@@ -46,7 +46,6 @@
 #include "data.h"
 #include "const.h"
 #include "debug.h"
-#include "platform.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -101,22 +100,13 @@ void U61_Data::unload()
 bool U61_Data::load1(char *name)
 {
     bool success=true;
-    char full_name[U61_STRING_SIZE];
     
-    /*
-     * adds the install path before the name of the data file
-     * under unix, INSTALL_DATA_PATH is usually /usr/local/share/u61/
-     * but under windows it would simply be ./
-     */
-    strcpy(full_name,U61_Platform::get_data_path());
-    strcat(full_name,name);
-
     /*
      * creation of the resource manager, which will be
      * used to load all the sections
      */
-    //cout<<"Loading data from \""<<full_name<<"\".\n";
-    manager=CL_ResourceManager::create(full_name,true);
+    //cout<<"Loading data from \""<<name<<"\".\n";
+    manager=CL_ResourceManager::create(name,true);
 
     if (manager!=NULL)
     {
@@ -494,6 +484,9 @@ bool U61_Data::load_back()
     back=CL_Surface::load(ID_BACK_MAIN,manager);
     success=success && (back!=NULL);
 
+    shade=CL_Surface::load(ID_SHADE,manager);
+    success=success && (shade!=NULL);
+
     if (!success)
     {
         cout<<"Back loading failed\n";
