@@ -112,6 +112,7 @@ public:
     CL_Surface *map[NB_MAP_MAX][NB_SIZE];
 
     CL_Surface *back;
+    CL_Surface *shade;
 
     CL_Surface *info[NB_SIZE];
 
@@ -196,6 +197,7 @@ protected:
     static char *const ID_MAP_NUMBER="map/number";
 
     static char *const ID_BACK_MAIN="back/main";
+    static char *const ID_SHADE="back/shade";
 
     static char *const ID_INFO_BIG="info/big";
     static char *const ID_INFO_SMALL="info/small";
