@@ -122,8 +122,30 @@ bool U61_Game::init()
   if (success)
     {
       //cout<<"Trying video mode\n";
-      CL_Display::set_videomode(U61_Global::data.screen_w,
-				U61_Global::data.screen_h,16,false);
+      try
+	{
+	  CL_Display::set_videomode(U61_Global::data.screen_w,
+				    U61_Global::data.screen_h,16,false);
+	}
+      catch (CL_Error e)
+	{
+          cout<<"Error setting 16-bit video mode : "
+	      <<e.message
+	      <<" , trying 8-bit\n";
+
+	  try
+            {
+	      CL_Display::set_videomode(U61_Global::data.screen_w,
+		  		      U61_Global::data.screen_h,8,false);
+	    }
+	  catch (CL_Error e)
+	    {
+	      cout<<"Error setting 8-bit video mode : "
+		  <<e.message
+		  <<" , giving up\n";
+	      success=false; 
+	    }
+	}
     }
 
   if (success)
@@ -240,10 +262,8 @@ void U61_Game::run()
       display();
       poll();
 
-      if (protocol!=NULL)
-        {
-	  network();
-        }
+      network();
+        
       poll();
       menu();
       poll();
@@ -400,11 +420,34 @@ void U61_Game::menu()
  */
 void U61_Game::network()
 {
+  int i;
+  int slot;
+
   //cout<<"Network polled\n"; 
-  if (protocol->send_all()==U61_Protocol::FAILED 
-      || protocol->recv_all()==U61_Protocol::FAILED)
+  if (protocol!=NULL)
     {
-      protocol->print_diagnostic();
+      if (protocol->send_all()==U61_Protocol::FAILED 
+	  || protocol->recv_all()==U61_Protocol::FAILED)
+	{
+	  protocol->print_diagnostic();
+	}
+      protocol->check_connection();
+    }
+  if (dispatcher!=NULL)
+    {
+      dispatcher->process();
+      for (i=0;i<U61_Dispatcher::MAX_PLAYER_ID;++i)
+	{
+          if (dispatcher->is_player_busy(i) && !exists_player_id(i))
+	    {
+              //cout<<"Should create player "<<i<<"\n";
+              slot=find_free_network_slot();
+              if (slot>=0)
+		{
+                  player[slot].init_network(dispatcher,i);
+		}
+	    }
+	}
     }
 }
 
@@ -439,20 +482,8 @@ void U61_Game::configure_hot()
  */
 void U61_Game::start_quick()
 {
-  int num;
-
   //cout<<"quick start\n";
-  if (standard_init())
-    {
-      dispatcher=new U61_LocalDispatcher();
-
-      num=get_local_player(0);
-      //cout<<"num="<<num<<"\n";
-      //cout<<"name="<<U61_Global::config.player[num].name<<"\n";
-      player[0].init_local(&(player_input[num]),0,
-			   &(U61_Global::config.player[num]));
-      layout.init_alone(&(player[0]));
-    }
+  start_local_alone();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -471,7 +502,8 @@ void U61_Game::start_local_alone()
       num=get_local_player(0);
       //cout<<"num="<<num<<"\n";
       //cout<<"name="<<U61_Global::config.player[num].name<<"\n";
-      player[0].init_local(&(player_input[num]),0,
+      player[0].init_local(&(player_input[num]),dispatcher,
+			   0,0,
 			   &(U61_Global::config.player[num]));
       layout.init_alone(&(player[0]));
     }
@@ -490,17 +522,19 @@ void U61_Game::start_local_multiplayer()
       dispatcher=new U61_LocalDispatcher();
 
       num0=get_local_player(0);
-      player[0].init_local(&(player_input[num0]),0,
+      player[0].init_local(&(player_input[num0]),dispatcher,
+			   0,0,
 			   &(U61_Global::config.player[num0]));
 
       num1=get_local_player(1);
       if (num1<0)
         {
-	  layout.init_alone(&(player[0]));
+	  layout.init_multiplayer_1(&(player[0]));
         }
       else
         {
-	  player[1].init_local(&(player_input[num1]),0,
+	  player[1].init_local(&(player_input[num1]),dispatcher,
+			       1,0,
 			       &(U61_Global::config.player[num1]));
 
 	  num2=get_local_player(2);
@@ -511,7 +545,8 @@ void U61_Game::start_local_multiplayer()
             }
 	  else
             {
-	      player[2].init_local(&(player_input[num2]),0,
+	      player[2].init_local(&(player_input[num2]),dispatcher,
+				   2,0,
 				   &(U61_Global::config.player[num2]));
                 
 	      num3=get_local_player(3);
@@ -523,7 +558,8 @@ void U61_Game::start_local_multiplayer()
                 }
 	      else
                 {
-		  player[3].init_local(&(player_input[num3]),0,
+		  player[3].init_local(&(player_input[num3]),dispatcher,
+				       3,0,
 				       &(U61_Global::config.player[num3]));
                     
 		  layout.init_multiplayer_4(&(player[0]),
@@ -542,16 +578,41 @@ void U61_Game::start_local_multiplayer()
  */
 void U61_Game::start_network_new()
 {
+  int num0,num1;
   U61_ServerDispatcher *d;
 
   //cout<<"new network game started\n";
   if (standard_init())
     {
       d=new U61_ServerDispatcher();
-      dispatcher=d;
+      dispatcher=d;     
+      
       protocol=new U61_ServerProtocol(d,
 				      U61_Global::config.network_port,
                                       U61_Global::config.network_channel);
+      
+      num0=get_local_player(0);
+      player[0].init_local(&(player_input[num0]),dispatcher,
+			   0,0,
+			   &(U61_Global::config.player[num0]));
+
+      num1=get_local_player(1);
+      if (num1<0)
+        {
+	  layout.init_network_1(&(player[0]),
+				&(player[U61_Layout::NB_PLAYERS_NET_LOCAL]));
+        }
+      else
+        {
+	  player[1].init_local(&(player_input[num1]),dispatcher,
+			       1,0,
+			       &(U61_Global::config.player[num1]));
+
+	 
+	  layout.init_network_2(&(player[0]),
+				&(player[1]),
+				&(player[U61_Layout::NB_PLAYERS_NET_LOCAL]));
+	}
     }
 }
 
@@ -564,17 +625,61 @@ void U61_Game::start_network_join()
   U61_ClientDispatcher *d;
 
   //cout<<"joining network game\n";
+  
   if (standard_init())
     {
       d=new U61_ClientDispatcher();
-      dispatcher=d;
+      dispatcher=d;     
+
       protocol=new U61_ClientProtocol(d,
 				      U61_Global::config.network_port,
                                       U61_Global::config.network_channel,
-				      U61_Global::config.server_id);
+                                      U61_Global::config.server_id);
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Second phase of client initialization, after this, players will be
+ * playing for good (ie network initializations have been completed)
+ */
+void U61_Game::do_network_join(char *script,
+			       int id0,int id1,
+			       int speed,int accel,
+			       int time)
+{
+  int num0,num1;
+
+  time_reset(time);
+  U61_Script::do_string(script);
+  initial_speed=speed;
+  acceleration=accel;
+
+  num0=get_local_player(0);
+  player[0].init_local(&(player_input[num0]),dispatcher,
+		       id0,time,
+		       &(U61_Global::config.player[num0]));
+
+  num1=get_local_player(1);
+  if (num1<0)
+    {
+      layout.init_network_1(&(player[0]),
+			    &(player[U61_Layout::NB_PLAYERS_NET_LOCAL]));
+    }
+  else
+    {
+      player[1].init_local(&(player_input[num1]),dispatcher,
+			   id1,time,
+			   &(U61_Global::config.player[num1]));
+
+	 
+      layout.init_network_2(&(player[0]),
+			    &(player[1]),
+			    &(player[U61_Layout::NB_PLAYERS_NET_LOCAL]));
+    }
+
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * stops all network activity
@@ -613,6 +718,8 @@ bool U61_Game::standard_init()
 {
   bool ok=true;
 
+  initial_speed=U61_Global::config.initial_speed;
+  acceleration=U61_Global::config.acceleration;
   configure_cold();
   configure_hot();
 
@@ -722,3 +829,120 @@ int U61_Game::get_local_player(int order)
 
   return result;
 }
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns a free even player id
+ */
+int U61_Game::find_free_player_id0()
+{
+  return find_free_player_id(0,2);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns a free odd player id
+ */
+int U61_Game::find_free_player_id1()
+{
+  return find_free_player_id(1,2);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns a free player id
+ */
+int U61_Game::find_free_player_id(int start,int step)
+{
+  int i,j;
+  int result=-1;
+  bool taken;
+
+  for (i=start;i<=U61_Dispatcher::MAX_PLAYER_ID-step;i+=step)
+    {
+      taken=false;
+      for (j=0;j<step;++j)
+	{
+          if (exists_player_id(i+j))
+	  {
+	    taken=true;
+	  }
+	}
+      if (!taken)
+	{
+	  result=i;
+	}
+    }
+
+  return result;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns a free network player slot. The slot is not hte same thing than
+ * the ID. The ID is used to stamp events whereas the slot is just 
+ * used as an index in the U61_Game::player array.
+ */
+int U61_Game::find_free_network_slot()
+{
+  int i;
+  int result=-1;
+
+  for (i=U61_Layout::NB_PLAYERS_NET_LOCAL;
+       i<U61_Layout::NB_PLAYERS_TOTAL;
+       ++i)
+    {
+      if (!player[i].is_available())
+	{
+	  result=i;
+	}
+    }
+
+  return result;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns true if there's an available player with this ID
+ */
+bool U61_Game::exists_player_id(int player_id)
+{
+  bool result=false;
+  int i;
+
+  for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
+    {
+      if (player[i].is_available() && player[i].get_id()==player_id)
+	{
+	  result=true;
+	}
+    }
+
+  return result;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Returns the player associated to a given id
+ * This function should never fail, if it does, it means there's something
+ * weird happening.
+ * Indeed, if no matching player is found, then a new player is created.
+ * In fact the only reason that would cause this function to fail would
+ * be more than 10 players playing together. And this should always be
+ * forbidden by the server.
+ */
+U61_Player *U61_Game::find_player_by_id(int id)
+{
+  U61_Player *result=NULL;
+  int i;
+
+  for (i=0;i<U61_Layout::NB_PLAYERS_TOTAL;++i)
+    {
+      if (player[i].is_available() && player[i].get_id()==id)
+	{
+          result=&(player[i]);
+	}
+    }
+
+  return result;
+}
