@@ -69,71 +69,86 @@
 
 class U61_Game
 { 
-public:
+ public:
 
-    U61_Game();
-    ~U61_Game();
-    bool init();
-    void deinit();
-    void run();
-    void quit();
+  U61_Game();
+  ~U61_Game();
+  bool init();
+  void deinit();
+  void run();
+  void quit();
 
-    void configure_cold();
-    void configure_hot();
-    void start_quick();
-    void start_local_alone();
-    void start_local_multiplayer();
-    void start_network_new();
-    void start_network_join();
-    void stop();
+  void configure_cold();
+  void configure_hot();
+  void start_quick();
+  void start_local_alone();
+  void start_local_multiplayer();
+  void start_network_new();
+  void start_network_join();
+  void do_network_join(char *script,
+		       int id0,int id1,
+		       int speed,int accel,
+		       int time);
+  void stop();
 
-    int get_local_player(int order);
+  int get_local_player(int order);
+  int find_free_player_id0();
+  int find_free_player_id1();
+  U61_Player *find_player_by_id(int id);
 
-    static const int NB_NET_GROUPS=5;
-protected:
-    U61_MenuInput menu_input;
-    U61_PlayerInput player_input[U61_Layout::NB_PLAYERS_LOCAL]; 
-    U61_Layout layout;
-    U61_Player player[U61_Layout::NB_PLAYERS_TOTAL];
-    U61_Protocol *protocol;
-    U61_Dispatcher *dispatcher;
+  static const int NB_NET_GROUPS=5;
 
-    bool standard_init();
-    void stop_network();
+  int initial_speed;
+  int acceleration;
 
-    void bind_keys();
-    void reset_players();
-    void pump_player_events();
+ protected:
+  U61_MenuInput menu_input;
+  U61_PlayerInput player_input[U61_Layout::NB_PLAYERS_LOCAL]; 
+  U61_Layout layout;
+  U61_Player player[U61_Layout::NB_PLAYERS_TOTAL];
+  U61_Protocol *protocol;
+  U61_Dispatcher *dispatcher;
 
-    void time_reset(int time=1);
+  bool standard_init();
+  void stop_network();
 
-    void poll();
-    void display();
-    void menu();
-    void logic();
-    void network();
+  void bind_keys();
+  void reset_players();
+  void pump_player_events();
 
-    U61_Menu *current_menu;
+  void time_reset(int time=1);
 
-    enum {STATE_RUN,STATE_QUIT};
+  void poll();
+  void display();
+  void menu();
+  void logic();
+  void network();
 
-    int state;
+  int find_free_player_id(int start, int step);
+  int find_free_network_slot();
+  bool exists_player_id(int player_id);
 
-    static const int MAX_LOGIC_PER_DISPLAY=50;
-    static const int MENU_POLL_DELAY=33;
+  U61_Menu *current_menu;
 
-    int last_clanlib_time_polled;
-    int last_u61_time_polled;
-    int last_menu_time_polled;
+  enum {STATE_RUN,STATE_QUIT};
+
+  int state;
+
+  static const int MAX_LOGIC_PER_DISPLAY=50;
+  static const int MENU_POLL_DELAY=33;
+
+  int last_clanlib_time_polled;
+  int last_u61_time_polled;
+  int last_menu_time_polled;
     
-    int calls_to_poll;
-    int calls_to_poll_clanlib;
-    int calls_to_poll_u61;
-    int calls_to_poll_menu;
+  int calls_to_poll;
+  int calls_to_poll_clanlib;
+  int calls_to_poll_u61;
+  int calls_to_poll_menu;
 
-    int calls_to_display;
-    int calls_to_menu;
-    int calls_to_logic;
+  int calls_to_display;
+  int calls_to_menu;
+  int calls_to_logic;
 };
 
 #endif
