@@ -53,35 +53,43 @@
 
 class U61_Layout
 {
-public:
-    U61_Layout();
-    ~U61_Layout();
+ public:
+  U61_Layout();
+  ~U61_Layout();
 
-    void reset();
+  void reset();
 
-    void init_alone(U61_Player *p);
-    void init_multiplayer_2(U61_Player *p1,
-                            U61_Player *p2);
-    void init_multiplayer_3(U61_Player *p1,
-                            U61_Player *p2,
-                            U61_Player *p3);
-    void init_multiplayer_4(U61_Player *p1,
-                            U61_Player *p2,
-                            U61_Player *p3,
-                            U61_Player *p4);
+  void init_alone(U61_Player *p);
+  void init_multiplayer_1(U61_Player *p1);
+  void init_multiplayer_2(U61_Player *p1,
+			  U61_Player *p2);
+  void init_multiplayer_3(U61_Player *p1,
+			  U61_Player *p2,
+			  U61_Player *p3);
+  void init_multiplayer_4(U61_Player *p1,
+			  U61_Player *p2,
+			  U61_Player *p3,
+			  U61_Player *p4);
+  void init_network_1(U61_Player *p1,
+                      U61_Player *net);
+  void init_network_2(U61_Player *p1,
+		      U61_Player *p2,
+                      U61_Player *net);
+                         
  
-    void draw();
+  void draw();
 
-    static const int NB_PLAYERS_LOCAL=4;
-    static const int NB_PLAYERS_NET_LOCAL=2;
-    static const int NB_PLAYERS_TOTAL=10;
+  static const int NB_PLAYERS_LOCAL=4;
+  static const int NB_PLAYERS_NET_LOCAL=2;
+  static const int NB_PLAYERS_TOTAL=10;
     
-protected:
-    U61_LayoutItem items[NB_PLAYERS_TOTAL];
-    CL_Canvas *background;
+ protected:
+  U61_LayoutItem items[NB_PLAYERS_TOTAL];
+  CL_Canvas *background;
     
-    bool exists_changed_background();
-    void prepare_background();
+  void init_network_common(U61_Player *net);
+  bool exists_changed_background();
+  void prepare_background();
 };
 
 #endif
