@@ -128,7 +128,8 @@ void U61_Map::begin()
   auto_events.clear();
     
   clear();
- 
+
+  name[0]=0; 
   block.reset();
   next_block.reset();
   block_requested=false;
@@ -451,8 +452,8 @@ void U61_Map::handle_event(U61_Event event)
     {
       if (int(event.time)<map_time)
         {
-	  cout<<"Inconsitency in event dates detected event_time="
-	      <<event.time<<" event_code="<<event.code<<" map_time="
+	  cout<<"Inconsitency in event dates detected event="
+	      <<event<<" map_time="
 	      <<map_time<<"\n";
         }  
       else
@@ -484,11 +485,14 @@ void U61_Map::handle_event(U61_Event event)
             case U61_Event::LOOSE:
 	      loose();
 	      break;
+            case U61_Event::NAME_LETTER:
+              name_add_letter(event.par);
+	      break;
             }
         }
     }
 
-  //cout<<"Event low level computed code="<<event.code<<"\n";
+  //cout<<"Event low level computed="<<event<<"\n";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -563,6 +567,15 @@ void U61_Map::put_auto_event(U61_Event event)
   auto_events.push_back(event);
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the name of the player playing on this map
+ */
+char *U61_Map::get_name()
+{
+  return name;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * draws the map onto the screen
@@ -961,6 +974,21 @@ void U61_Map::block_drop()
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Adds a letter to the map name
+ */
+void U61_Map::name_add_letter(char c)
+{
+  int len;
+
+  len=strlen(name);
+  if (len<NAME_SIZE)
+    {
+      name[len]=c;
+      name[len+1]=0;
+    }
+}
 
 /*--------------------------------------------------------------------------*/
 /*
