@@ -110,6 +110,8 @@ public:
     void set_accel(int a);
     int get_accel();
 
+    char *get_name();
+
     void blow_up_square(int x, int y);
     bool is_square_exploding(int x,int y);
     bool exists_explosion();
@@ -118,6 +120,7 @@ public:
 
     static const int WIDTH=10;
     static const int HEIGHT=25;
+    static const int NAME_SIZE=8;
     static const int NB_GLOBAL=1000;
     static const int SPEED_SCALE=1000;
     static const int ACCEL_SCALE=100000;
@@ -136,6 +139,7 @@ protected:
     U61_Block block_prevision;
     list<U61_Event> auto_events;
     int global_val[NB_GLOBAL];
+    char name[NAME_SIZE+1];
 
     int background;
     bool active;
@@ -170,6 +174,8 @@ protected:
     void block_move_down();
     void block_drop();
 
+    void name_add_letter(char c);
+
     bool is_block_active();
     bool is_block_ok(U61_Block *test);
   
