@@ -55,16 +55,16 @@
  */
 char *U61_Menu::bottom_message[BOTTOM_MESSAGE_NB]=
 {
-    "U61, another block-based game by U-Foot",
-    "Copyright (C) 2000 Christian Mauduit",
-    "Home page : http://www.ufoot.org/u61",
-    "Contact author : ufoot@ufoot.org",
-    "Use the arrows to navigate through the menus",
-    "Press escape to return to the previous menu",
-    "Game rules can be changed easily by writing new lua scripts, try it!",
-    "This is only an alpha version...",
-    "U61 uses ClanLib http://clanlib.org",
-    "Graphics by U-Woman http://www.adlerhome.com"
+  "U61, another block-based game by U-Foot",
+  "Copyright (C) 2000 Christian Mauduit",
+  "Home page : http://www.ufoot.org/u61",
+  "Contact author : ufoot@ufoot.org",
+  "Use the arrows to navigate through the menus",
+  "Press escape to return to the previous menu",
+  "Game rules can be changed easily by writing new lua scripts, try it!",
+  "This is only an alpha version...",
+  "U61 uses ClanLib http://clanlib.org",
+  "Graphics by U-Woman http://www.adlerhome.com"
 };
 
 /*--------------------------------------------------------------------------*/
@@ -85,9 +85,10 @@ int U61_Menu::bottom_message_width=-1000000;
  */ 
 U61_Menu::U61_Menu(U61_Menu *parent,char *top)
 {
-    parent_menu=parent;
-    top_message=top;
-    message_active=true;
+  parent_menu=parent;
+  top_message=top;
+  message_active=true;
+  shaded=false;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -96,13 +97,13 @@ U61_Menu::U61_Menu(U61_Menu *parent,char *top)
  */ 
 U61_Menu::~U61_Menu()
 {
-    int i;
-    int nb_item;
+  int i;
+  int nb_item;
 
-    nb_item=items.size();
-    for (i=0;i<nb_item;++i)
+  nb_item=items.size();
+  for (i=0;i<nb_item;++i)
     {
-        delete items[i];
+      delete items[i];
     }
 }
 
@@ -112,52 +113,52 @@ U61_Menu::~U61_Menu()
  */
 U61_Menu *U61_Menu::action(int key)
 {
-    U61_Menu *next_menu;
-    int old_selection;
+  U61_Menu *next_menu;
+  int old_selection;
 
-    next_menu=this;
-    old_selection=selection;
+  next_menu=this;
+  old_selection=selection;
 
-    if (!(items[selection]->is_modal()))
+  if (!(items[selection]->is_modal()))
     {
-        switch (key)
+      switch (key)
         {
         case U61_MenuInput::KEY_UP:
-            select_up();
-            break;
+	  select_up();
+	  break;
         case U61_MenuInput::KEY_DOWN:
-            select_down();
-            break;
+	  select_down();
+	  break;
         case U61_MenuInput::KEY_ESCAPE:
-            next_menu=back();
-            break;
+	  next_menu=back();
+	  break;
         case U61_MenuInput::KEY_ENTER:
-            next_menu=validate();
-            break;
+	  next_menu=validate();
+	  break;
         }
     }
 
-    if (items[selection]->action(key))
+  if (items[selection]->action(key))
     {
-        U61_Sound::play_menu_move();
+      U61_Sound::play_menu_move();
     }
 
-    items[selection]->update();
-    items[selection]->select();
+  items[selection]->update();
+  items[selection]->select();
 
-    if (next_menu!=this)
+  if (next_menu!=this)
     {
-        U61_Sound::play_menu_validate();
+      U61_Sound::play_menu_validate();
     }
-    else
+  else
     {
-        if (old_selection!=selection)
+      if (old_selection!=selection)
         {
-            U61_Sound::play_menu_move();
+	  U61_Sound::play_menu_move();
         }
     }
 
-    return next_menu;
+  return next_menu;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -166,7 +167,7 @@ U61_Menu *U61_Menu::action(int key)
  */
 U61_Menu *U61_Menu::validate()
 {
-    return this;
+  return this;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -175,7 +176,7 @@ U61_Menu *U61_Menu::validate()
  */
 U61_Menu *U61_Menu::back()
 {
-    return get_parent();
+  return get_parent();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -184,31 +185,36 @@ U61_Menu *U61_Menu::back()
  */
 void U61_Menu::draw()
 {
-    int y;
-    int i;
-    int nb_item;
-    int last_item_height2;
-    int item_height;
+  int y;
+  int i;
+  int nb_item;
+  int last_item_height2;
+  int item_height;
 
-    y=U61_Global::data.screen_h/2;
-
-    y-=get_height()/2;
-    last_item_height2=0;
-
-    nb_item=items.size();
-    for (i=0;i<nb_item;++i)
+  if (shaded)
     {
-        item_height=items[i]->get_height();
-
-        y+=last_item_height2+item_height/2;
-        items[i]->draw(y);
-        last_item_height2=item_height-item_height/2;
+      U61_Global::data.shade->put_screen(0,0);
     }
 
-    if (message_active)
+  y=U61_Global::data.screen_h/2;
+
+  y-=get_height()/2;
+  last_item_height2=0;
+
+  nb_item=items.size();
+  for (i=0;i<nb_item;++i)
     {
-        draw_top_message();
-        draw_bottom_message();
+      item_height=items[i]->get_height();
+
+      y+=last_item_height2+item_height/2;
+      items[i]->draw(y);
+      last_item_height2=item_height-item_height/2;
+    }
+
+  if (message_active)
+    {
+      draw_top_message();
+      draw_bottom_message();
     }
 }
 
@@ -218,16 +224,16 @@ void U61_Menu::draw()
  */
 int U61_Menu::get_height()
 {
-    int i;
-    int nb_item;
-    int height=0;
+  int i;
+  int nb_item;
+  int height=0;
 
-    nb_item=items.size();
-    for (i=0;i<nb_item;++i)
+  nb_item=items.size();
+  for (i=0;i<nb_item;++i)
     {
-        height+=items[i]->get_height();
+      height+=items[i]->get_height();
     }
-    return height;
+  return height;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -236,16 +242,16 @@ int U61_Menu::get_height()
  */
 int U61_Menu::get_width()
 {
-    int i;
-    int nb_item;
-    int width=0;
+  int i;
+  int nb_item;
+  int width=0;
 
-    nb_item=items.size();
-    for (i=0;i<nb_item;++i)
+  nb_item=items.size();
+  for (i=0;i<nb_item;++i)
     {
-        width=max(items[i]->get_width(),width);
+      width=max(items[i]->get_width(),width);
     }
-    return width;
+  return width;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -254,22 +260,23 @@ int U61_Menu::get_width()
  */
 void U61_Menu::select(int num_item)
 {
-    int nb_item;
-    int i;
+  int nb_item;
+  int i;
 
-    nb_item=items.size();
-    for (i=0;i<nb_item;++i)
+  //cout<<"Selecting item "<<num_item<<"\n";
+  nb_item=items.size();
+  for (i=0;i<nb_item;++i)
     {
-        if (i==num_item)
+      if (i==num_item)
         {
-            items[i]->select();
+	  items[i]->select();
         }
-        else
+      else
         {
-            items[i]->unselect();
+	  items[i]->unselect();
         }
     }
-    selection=num_item;
+  selection=num_item;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -278,13 +285,13 @@ void U61_Menu::select(int num_item)
  */
 void U61_Menu::select_up()
 {
-    if (selection>0)
+  if (selection>0)
     {
-        select(selection-1);
+      select(selection-1);
     }
-    else
+  else
     {
-        select(items.size()-1);
+      select(items.size()-1);
     }
 }
 
@@ -294,13 +301,13 @@ void U61_Menu::select_up()
  */
 void U61_Menu::select_down()
 {
-    if (selection<int(items.size())-1)
+  if (selection<int(items.size())-1)
     {
-        select(selection+1);
+      select(selection+1);
     }
-    else
+  else
     {
-        select(0);
+      select(0);
     }
 }
 
@@ -310,7 +317,7 @@ void U61_Menu::select_down()
  */
 U61_Menu *U61_Menu::get_parent()
 {
-    return parent_menu;
+  return parent_menu;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -321,7 +328,7 @@ U61_Menu *U61_Menu::get_parent()
  */
 void U61_Menu::add_item(U61_MenuItem *item)
 {
-    items.push_back(item);
+  items.push_back(item);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -330,13 +337,13 @@ void U61_Menu::add_item(U61_MenuItem *item)
  */
 void U61_Menu::draw_top_message()
 {
-    int x,y;
+  int x,y;
 
-    x=(U61_Global::data.screen_w-
-       U61_Global::data.font_menu->get_text_width(top_message))/2;
-    y=0;
+  x=(U61_Global::data.screen_w-
+     U61_Global::data.font_menu->get_text_width(top_message))/2;
+  y=0;
 
-    U61_Global::data.font_menu->print_left(x,y,top_message);
+  U61_Global::data.font_menu->print_left(x,y,top_message);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -345,21 +352,21 @@ void U61_Menu::draw_top_message()
  */
 void U61_Menu::draw_bottom_message()
 {
-    int x,y=0,dx;
+  int x,y=0,dx;
 
-    dx=(U61_Time::for_effect()-bottom_message_start_time)
-        /BOTTOM_MESSAGE_DELAY;
-    if (dx>=U61_Global::data.screen_w+bottom_message_width)
+  dx=(U61_Time::for_effect()-bottom_message_start_time)
+    /BOTTOM_MESSAGE_DELAY;
+  if (dx>=U61_Global::data.screen_w+bottom_message_width)
     {
-        init_bottom_message(); 
-        dx=0;
+      init_bottom_message(); 
+      dx=0;
     }
 
-    x=U61_Global::data.screen_w-dx;
-    y=U61_Global::data.screen_h-U61_Global::data.font_menu->get_height();
+  x=U61_Global::data.screen_w-dx;
+  y=U61_Global::data.screen_h-U61_Global::data.font_menu->get_height();
 
-    U61_Global::data.font_menu->print_left
-        (x,y,bottom_message[current_bottom_message]);
+  U61_Global::data.font_menu->print_left
+    (x,y,bottom_message[current_bottom_message]);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -368,15 +375,35 @@ void U61_Menu::draw_bottom_message()
  */
 void U61_Menu::init_bottom_message()
 {
-    current_bottom_message++;
-    if (current_bottom_message>=BOTTOM_MESSAGE_NB)
+  current_bottom_message++;
+  if (current_bottom_message>=BOTTOM_MESSAGE_NB)
     {
-        current_bottom_message=0;
+      current_bottom_message=0;
     }
 
-    bottom_message_start_time=U61_Time::for_effect();
+  bottom_message_start_time=U61_Time::for_effect();
 
-    bottom_message_width=U61_Global::data.font_menu->get_text_width
-        (bottom_message[current_bottom_message]);
+  bottom_message_width=U61_Global::data.font_menu->get_text_width
+    (bottom_message[current_bottom_message]);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Shades what's behind the menu, usefull when in-game: on may wish
+ * not to have all the fashing battlefield behind the font
+ */
+void U61_Menu::shade()
+{
+  shaded=true;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Unshades what's behind the menu, (the contrary of shade())
+ * This is the default behavior
+ */
+void U61_Menu::unshade()
+{
+  shaded=false;
 }
 
