@@ -51,40 +51,44 @@
 
 class U61_Menu
 {
-public:
-    U61_Menu(U61_Menu *parent, char *top);
-    virtual ~U61_Menu();
+ public:
+  U61_Menu(U61_Menu *parent, char *top);
+  virtual ~U61_Menu();
     
-    U61_Menu *action(int key);
-    virtual U61_Menu *validate();
-    virtual U61_Menu *back();
-    void draw();
-    void select(int num_item);
-    virtual void select_up();
-    virtual void select_down();
-    int get_height();
-    int get_width();
-    void add_item(U61_MenuItem *item);
-    U61_Menu *get_parent();
+  U61_Menu *action(int key);
+  virtual U61_Menu *validate();
+  virtual U61_Menu *back();
+  void draw();
+  void select(int num_item);
+  virtual void select_up();
+  virtual void select_down();
+  int get_height();
+  int get_width();
+  void add_item(U61_MenuItem *item);
+  U61_Menu *get_parent();
 
-protected:
-    vector<U61_MenuItem *> items;
-    U61_Menu *parent_menu;    
-    int selection;
-    char *top_message;
+  void shade();
+  void unshade();
 
-    bool message_active;
+ protected:
+  vector<U61_MenuItem *> items;
+  U61_Menu *parent_menu;    
+  int selection;
+  char *top_message;
 
-    void draw_top_message();
-    void draw_bottom_message();
-    void init_bottom_message();
+  bool shaded;
+  bool message_active;
 
-    const static int BOTTOM_MESSAGE_NB=10;
-    const static int BOTTOM_MESSAGE_DELAY=2;
-    static int current_bottom_message;
-    static int bottom_message_start_time;
-    static int bottom_message_width;
-    static char *bottom_message[BOTTOM_MESSAGE_NB];
+  void draw_top_message();
+  void draw_bottom_message();
+  void init_bottom_message();
+
+  const static int BOTTOM_MESSAGE_NB=10;
+  const static int BOTTOM_MESSAGE_DELAY=2;
+  static int current_bottom_message;
+  static int bottom_message_start_time;
+  static int bottom_message_width;
+  static char *bottom_message[BOTTOM_MESSAGE_NB];
 };
 
 #endif
