@@ -58,6 +58,9 @@
 #include "player.h"
 #include "time.h"
 #include "localsource.h"
+#include "localcopy.h"
+#include "networksource.h"
+#include "networkcopy.h"
 #include "global.h"
 
 /*---------------------------------------------------------------------------
@@ -75,10 +78,10 @@
  */ 
 U61_Player::U61_Player()
 {
-    source=NULL;
-    copy=NULL;
+  source=NULL;
+  copy=NULL;
 
-    reset();
+  reset();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -96,16 +99,17 @@ U61_Player::~U61_Player()
  */
 void U61_Player::reset()
 {
-    available=false;
-    if (source!=NULL)
+  available=false;
+
+  if (source!=NULL)
     {
-        delete source;
-        source=NULL;
+      delete source;
+      source=NULL;
     }
-    if (copy!=NULL)
+  if (copy!=NULL)
     {
-        delete copy;
-        copy=NULL;
+      delete copy;
+      copy=NULL;
     }
 }
 
@@ -115,7 +119,7 @@ void U61_Player::reset()
  */
 void U61_Player::set_id(int player_id)
 {
-    id=player_id;
+  id=player_id;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -124,7 +128,7 @@ void U61_Player::set_id(int player_id)
  */
 int U61_Player::get_id()
 {
-    return id;
+  return id;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -133,7 +137,7 @@ int U61_Player::get_id()
  */
 char *U61_Player::get_name()
 {
-    return name;
+  return sure.get_name();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -142,7 +146,7 @@ char *U61_Player::get_name()
  */
 int U61_Player::get_score()
 {
-    return last.get_score();
+  return last.get_score();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -151,7 +155,7 @@ int U61_Player::get_score()
  */
 int U61_Player::get_best_score()
 {
-    return sure.get_best_score();
+  return sure.get_best_score();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -160,44 +164,80 @@ int U61_Player::get_best_score()
  */
 U61_Block U61_Player::get_next_block()
 {
-    return last.get_next_block();
+  return last.get_next_block();
 }
 
 /*--------------------------------------------------------------------------*/
 /*
  * sets the player as a local player
+ * Note that even if the game is a networked game, local players are
+ * initialized with this function
  */
-void U61_Player::init_local(U61_Input *input,int time,
-                           U61_PlayerConfig *conf,
-                           bool start)
+void U61_Player::init_local(U61_Input *input,
+                            U61_Dispatcher *d,
+			    int id,
+			    int time,
+			    U61_PlayerConfig *conf,
+			    bool start)
 {
-    U61_LocalSource *keybd; 
+  U61_LocalSource *src; 
+  U61_LocalCopy *cpy;
 
-    reset();
-    sure.reset(U61_Global::config.initial_speed,
-               U61_Global::config.acceleration);
-    copy_sure_to_last();
-    name=conf->name;
-    prevision=&(conf->prevision);
-    //cout<<"init local with "<<name<<"\n";
+  reset();
 
-    keybd=new U61_LocalSource(input,&sure);
-    if (start)
+  local=true;
+
+  set_id(id);
+  sure.reset(U61_Global::game.initial_speed,
+	     U61_Global::game.acceleration);
+  copy_sure_to_last();
+
+  prevision=&(conf->prevision);
+
+  src=new U61_LocalSource(input,&sure,d,id,conf->name);
+  if (start)
     {
-        keybd->send_start_stop(time);
+      src->send_start_stop(time);
     }
-    source=keybd;
-    available=true;
+
+  cpy=new U61_LocalCopy(id,d);
+
+  source=src;
+  copy=cpy;
+
+  available=true;
 }
 
 /*--------------------------------------------------------------------------*/
 /*
  * sets the player as a network player
  */
-void U61_Player::init_network()
+void U61_Player::init_network(U61_Dispatcher *d,
+                              int id)
 {
-    reset();
-    //available=true;
+  U61_NetworkSource *src; 
+  U61_NetworkCopy *cpy;
+
+  reset();
+
+  local=false;
+
+  set_id(id);
+  sure.reset(U61_Global::game.initial_speed,
+	     U61_Global::game.acceleration);
+  copy_sure_to_last();
+
+  prevision=&(U61_Global::config.network_prevision);
+
+  src=new U61_NetworkSource(d,&sure,id);
+  cpy=new U61_NetworkCopy(id,d);
+
+  source=src;
+  copy=cpy;
+
+  //cout<<"Starting network player "<<id<<"\n";
+
+  available=true;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -206,7 +246,16 @@ void U61_Player::init_network()
  */
 bool U61_Player::is_available()
 {
-    return available;
+  return available;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns true if the player is a local player
+ */
+bool U61_Player::is_local()
+{
+  return local;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -218,20 +267,35 @@ bool U61_Player::is_available()
  */
 void U61_Player::pump_events()
 {
-    bool changed=false;
+  bool changed=false;
+  U61_Event evt;
+  bool kill_needed=false;
 
-    source->poll();
+  source->poll();
 
-    while((!source->empty()) && 
+  while((!source->empty()) && 
         ((int)(source->check().time))<=U61_Time::for_logic())
     {
-        changed=true;
-        U61_Player::handle_event(source->get());
+      changed=true;
+      evt=source->get();
+      U61_Player::handle_event(evt);
+      copy->put(evt);
+      if (evt.code==U61_Event::KILL)
+	{
+	  kill_needed=true;
+	}
     }
 
-    if (changed)
+  if (changed)
     {
-        copy_sure_to_last();
+      copy_sure_to_last();
+    }
+
+  copy->flush();
+
+  if (kill_needed)
+    {
+      kill();
     }
 }
 
@@ -241,24 +305,23 @@ void U61_Player::pump_events()
  */
 void U61_Player::handle_event(U61_Event evt)
 {
-//    cout<<"Event pumped code="<<evt.code<<"\n";
-    if (sure.is_active())
-    {
-        if (evt.code==U61_Event::START_STOP)
-        {
-	    stop();
-        }
-        else
-        {
-            sure.handle_event(evt);
-        }
-    }
-    else
-    {
-        if (evt.code==U61_Event::START_STOP)
-        {
-            start(evt.time);
-        } 
+      if (sure.is_active())
+	{
+	  if (evt.code==U61_Event::START_STOP)
+	    {
+	      stop();
+	    }
+	  else
+	    {
+	      sure.handle_event(evt);
+	    }
+	}
+      else
+	{
+	  if (evt.code==U61_Event::START_STOP)
+	    {
+	      start(evt.time);
+	    } 
     }
 }
 
@@ -268,9 +331,9 @@ void U61_Player::handle_event(U61_Event evt)
  */
 void U61_Player::start(int time)
 {
-    sure.set_active(time);
-    copy_sure_to_last();
-    //cout<<"Player "<<id<<" started\n";
+  sure.set_active(time);
+  copy_sure_to_last();
+  //cout<<"Player "<<id<<" started\n";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -279,9 +342,22 @@ void U61_Player::start(int time)
  */
 void U61_Player::stop()
 {
-    sure.set_inactive();
-    copy_sure_to_last();
-    //cout<<"Player "<<id<<" stopped\n";
+  sure.set_inactive();
+  copy_sure_to_last();
+  //cout<<"Player "<<id<<" stopped\n";
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * called to kill a player. This is stronger than a stop, it should
+ * happen when a remote network players quits the game.
+ * In this case we kill the player to free the player slot.
+ */
+void U61_Player::kill()
+{
+  reset();
+  //available=false;
+  //cout<<"Player "<<id<<" killed\n";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -290,9 +366,9 @@ void U61_Player::stop()
  */
 void U61_Player::draw(int x,int y,int size)
 {
-    last.anticipate(U61_Time::for_event());
-    //last.draw(10,10);
-    last.draw(x,y,size,*prevision);
+  last.anticipate(U61_Time::for_event());
+  //last.draw(10,10);
+  last.draw(x,y,size,*prevision);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -301,6 +377,6 @@ void U61_Player::draw(int x,int y,int size)
  */
 void U61_Player::copy_sure_to_last()
 {
-    last=sure;
-    last.mute();
+  last=sure;
+  last.mute();
 }
