@@ -65,6 +65,7 @@
 #include "eventsource.h"
 #include "eventcopy.h"
 #include "input.h"
+#include "dispatcher.h"
 
 /*---------------------------------------------------------------------------
  classes
@@ -72,48 +73,56 @@
 
 class U61_Player
 { 
-public:
-    U61_Player();
-    ~U61_Player();  
+ public:
+  U61_Player();
+  ~U61_Player();  
 
-    void reset();
+  void reset();
 
-    void set_id(int player_id);
-    int get_id();
+  void set_id(int player_id);
+  int get_id();
 
-    char *get_name();
-    int get_score();
-    int get_best_score();
-    U61_Block get_next_block();
+  char *get_name();
+  int get_score();
+  int get_best_score();
+  U61_Block get_next_block();
 
-    void init_local(U61_Input *input,int time,
-                    U61_PlayerConfig *conf,
-                    bool start=true);
-    void init_network();
+  void init_local(U61_Input *input,
+                  U61_Dispatcher *d,
+		  int id,
+		  int time,
+		  U61_PlayerConfig *conf,
+		  bool start=true);
+  void init_network(U61_Dispatcher *d,
+		    int id);
 
-    bool is_available();
+  bool is_available();
+  bool is_local();
 
-    void pump_events();
+  void pump_events();
 
-    void draw(int x,int y,int size=U61_Data::SIZE_BIG);
-protected:
-    int id;
-    char *name;
+  void draw(int x,int y,int size=U61_Data::SIZE_BIG);
 
-    bool available;
-    U61_EventSource *source;
-    U61_EventCopy *copy;
+  void kill();
+ protected:
+  int id;
 
-    U61_Map last;
-    U61_Map sure;
+  bool available;
+  bool local;
 
-    bool *prevision;
+  U61_EventSource *source;
+  U61_EventCopy *copy;
 
-    void handle_event(U61_Event evt);
-    void start(int time);
-    void stop();
+  U61_Map last;
+  U61_Map sure;
 
-    void copy_sure_to_last();
+  bool *prevision;
+
+  void handle_event(U61_Event evt);
+  void start(int time);
+  void stop();
+
+  void copy_sure_to_last();
 };
 
 #endif
