@@ -75,6 +75,7 @@ public:
     static void block_land(U61_Map *m,U61_Block *b);
     static bool map_match_pattern(U61_Map *m);
     static void map_time_callback(U61_Map *m,U61_Block *b);
+    static void map_square_blown_up(U61_Map *m,int x,int y);
 
     static char *const LUA_BLOCK_SHAPE="user_block_shape";
     static char *const LUA_BLOCK_ROTATE_LEFT="user_block_rotate_left";
@@ -85,6 +86,7 @@ public:
     static char *const LUA_BLOCK_LAND="user_block_land";
     static char *const LUA_MAP_MATCH_PATTERN="user_map_match_pattern";
     static char *const LUA_MAP_TIME_CALLBACK="user_map_time_callback";
+    static char *const LUA_MAP_SQUARE_BLOWN_UP="user_map_square_blown_up";
 
     static char *const C_BLOCK_RESET="u61_block_reset";
     static char *const C_BLOCK_CENTER="u61_block_center";
@@ -115,6 +117,8 @@ public:
     static char *const C_MAP_SET_PREVISION_STATE="u61_map_set_prevision_state";
     static char *const C_MAP_GET_PREVIEW_STATE="u61_map_get_preview_state";
     static char *const C_MAP_SET_PREVIEW_STATE="u61_map_set_preview_state";
+    static char *const C_MAP_BLOW_UP_SQUARE="u61_map_blow_up_square";
+    static char *const C_MAP_IS_SQUARE_EXPLODING="u61_map_is_square_exploding";
 
 protected:
     static void secure_pointers();
